library(Seurat)
library(ggplot2)
library(dplyr)
library(openxlsx)

# Set Folders
wdir <- "./Clustering_Analysis"

# Figure 5A - Center
df <- read.xlsx(xlsxFile = paste(wdir, "Full_T_Myelo_metadata.xlsx", sep = "/"), sheet = "Full")
df$AnnotationRaw <- as.factor(df$AnnotationRaw)

p <- ggplot(data = df, mapping = aes(x = UMAPh_1, y = UMAPh_2, color = AnnotationRaw)) +
  theme_void(base_size = 12) +
  theme(legend.position = "none") +
  geom_point(size = .3)
Seurat::LabelClusters(plot = p, id = "AnnotationRaw", color = "black", size = 5)

# Figure 5A - T cells
df_t <- read.xlsx(xlsxFile = paste(wdir, "Full_T_Myelo_metadata.xlsx", sep = "/"), sheet = "Tcell")
df_t$Annotation <- as.factor(df_t$Annotation)

p_t <- ggplot(data = df_t, mapping = aes(x = UMAPh_1, y = UMAPh_2, color = Annotation)) +
  theme_void(base_size = 12) +
  theme(legend.position = "none") +
  geom_point(size = .6)
Seurat::LabelClusters(plot = p_t, id = "Annotation", color = "black", size = 5)

ggplot(data = df_t, mapping = aes(x = UMAPh_1, y = UMAPh_2)) +
  theme_void(base_size = 12) +
  theme(legend.position = "none") +
  geom_point(data = subset(df_t, is.na(CART_MAGIC)), size = .6, color = "grey80") +
  geom_point(data = subset(df_t, CART_MAGIC == "CART_MAGIC"), size = .6, color = "darkred")

# Figure 5A - Myeloid cells
df_m <- read.xlsx(xlsxFile = paste(wdir, "Full_T_Myelo_metadata.xlsx", sep = "/"), sheet = "Myeloid")
df_m$Annotation <- as.factor(df_m$Annotation)
p_m <- ggplot(data = df_m, mapping = aes(x = UMAPh_1, y = UMAPh_2, color = Annotation)) +
  theme_void(base_size = 12) +
  theme(legend.position = "none") +
  geom_point(size = .6)
Seurat::LabelClusters(plot = p_m, id = "Annotation", color = "black", size = 5)

